==> crowd-integration-api-3.7.1-sources.jar: com/atlassian/crowd/model/application/ApplicationAttributeConstants.java <==
package com.atlassian.crowd.model.application;

/**
 * Constants for attributes of an application.
 *
 * @since v2.1
 */
public class ApplicationAttributeConstants {
    /**
     * Key of attribute indicating whether the application password has been encoded with the Atlassian SHA1 algorithm.
     */
    public static final String ATTRIBUTE_KEY_ATLASSIAN_SHA1_APPLIED = "atlassian_sha1_applied";

    /**
     * Key of attribute storing the value of the Application URL.
     */
    public static final String ATTRIBUTE_KEY_APPLICATION_URL = "applicationURL";

    /**
     * Key of attribute indicating whether the user and group names returned should be in lowercase.
     */
    public static final String ATTRIBUTE_KEY_LOWER_CASE_OUTPUT = "lowerCaseOutput";

    /**
     * Key of attribute indicating whether aliasing is enabled for the application.
     */
    public static final String ATTRIBUTE_KEY_ALIASING_ENABLED = "aliasingEnabled";

    /**
     * Key of attribute indicating whether memberships are aggregated across mapped directories.
     */
    public static final String ATTRIBUTE_KEY_AGGREGATE_MEMBERSHIPS = "aggregateMemberships";

    /**
     * Key of attribute indicating the application link ID
     */
    public static final String ATTRIBUTE_KEY_APPLICATION_LINK_ID = "applicationLinkId";

    /**
     * Key of attribute indicating the value of the interval for licensing data sync interval
     */
    public static final String ATTRIBUTE_KEY_LICENSE_DATA_SYNC_INTERVAL_IN_MIN = "licenseDataSyncInterval";

    /**
     * Key of attribute indicating the value of the last license data sync state
     */
    public static final String ATTRIBUTE_KEY_LAST_LICENSE_DATA_SYNC_STATUS = "lastLicenseDataSyncStatus";

    /**
     * Key of attribute indicating the timestamp when last license data sync state was updated
     */
    public static final String ATTRIBUTE_KEY_LAST_LICENSE_DATA_SYNC_STATUS_TIMESTAMP = "lastLicenseDataSyncStatusTimestamp";

    private ApplicationAttributeConstants() {
    } // prevent instantiation
}

==> crowd-integration-api-4.3.10-sources.jar: com/atlassian/crowd/model/application/ApplicationAttributeConstants.java <==
package com.atlassian.crowd.model.application;

/**
 * Constants for attributes of an application.
 *
 * @since v2.1
 */
public class ApplicationAttributeConstants {
    /**
     * Key of attribute indicating whether the application password has been encoded with the Atlassian SHA1 algorithm.
     */
    public static final String ATTRIBUTE_KEY_ATLASSIAN_SHA1_APPLIED = "atlassian_sha1_applied";

    /**
     * Key of attribute storing the value of the Application URL.
     */
    public static final String ATTRIBUTE_KEY_APPLICATION_URL = "applicationURL";

    /**
     * Key of attribute indicating whether the user and group names returned should be in lowercase.
     */
    public static final String ATTRIBUTE_KEY_LOWER_CASE_OUTPUT = "lowerCaseOutput";

    /**
     * Key of attribute indicating whether aliasing is enabled for the application.
     */
    public static final String ATTRIBUTE_KEY_ALIASING_ENABLED = "aliasingEnabled";

    /**
     * Key of attribute indicating whether memberships are aggregated across mapped directories.
     */
    public static final String ATTRIBUTE_KEY_AGGREGATE_MEMBERSHIPS = "aggregateMemberships";

    /**
     * Key of attribute indicating whether order of directories should be optimized for authentication basing on directory cache.
     */
    public static final String ATTRIBUTE_KEY_OPTIMISE_CACHED_DIRECTORIES_AUTHENTICATION_ORDER = "optimizeCachedDirectoriesAuthenticationAuthenticationOrder";

    /**
     * Key of attribute indicating the application link ID
     */
    public static final String ATTRIBUTE_KEY_APPLICATION_LINK_ID = "applicationLinkId";

    /**
     * Key of attribute indicating the value of the interval for licensing data sync interval
     */
    public static final String ATTRIBUTE_KEY_LICENSE_DATA_SYNC_INTERVAL_IN_MIN = "licenseDataSyncInterval";

    /**
     * Key of attribute indicating the value of the last license data sync state
     */
    public static final String ATTRIBUTE_KEY_LAST_LICENSE_DATA_SYNC_STATUS = "lastLicenseDataSyncStatus";

    /**
     * Key of attribute indicating the timestamp when last license data sync state was updated
     */
    public static final String ATTRIBUTE_KEY_LAST_LICENSE_DATA_SYNC_STATUS_TIMESTAMP = "lastLicenseDataSyncStatusTimestamp";

    /**
     * Key of attribute indicating whether user queries should return only users with access.
     */
    public static final String ATTRIBUTE_KEY_FILTER_USERS_WITH_ACCESS = "filterUsersWithAccess";
    /**
     * Key of attribute indicating whether group queries should return only groups with access.
     */
    public static final String ATTRIBUTE_KEY_FILTER_GROUPS_WITH_ACCESS = "filterGroupsWithAccess";

    /**
     * Key of attribute indicating whether application can authenticate user without passing their password.
     */
    public static final String AUTHENTICATION_WITHOUT_PASSWORD_ENABLED = "insecureAuthenticationEnabled";

    private ApplicationAttributeConstants() {
    } // prevent instantiation
}
